import numpy as np
from PIL import Image as Image
from _typeshed import Incomplete
from edgeiq._constants import EDGEIQ_LOGS as EDGEIQ_LOGS
from edgeiq._production_client import PRODUCTION_CLIENT as PRODUCTION_CLIENT
from edgeiq.base_service import BaseService as BaseService
from edgeiq.engine_accelerator import Engine as Engine
from edgeiq.model_config import ModelConfig as ModelConfig
from edgeiq.processing import ReIdentificationProcessor as ReIdentificationProcessor
from edgeiq.tools import to_json_serializable as to_json_serializable
from torchvision.transforms import Compose as Compose, Normalize as Normalize, Resize as Resize, ToTensor as ToTensor
from typing import List, Optional

SUPPORTED_ENGINES: Incomplete
torch_installed: bool

class ReIdentificationPrediction:
    def __init__(self, id: int, rank: int, distance: float) -> None: ...
    def __eq__(self, other) -> bool: ...
    @property
    def id(self) -> int: ...
    @property
    def rank(self) -> int: ...
    @property
    def distance(self) -> float: ...

class ReIdentificationResults:
    def __init__(self, predictions: List[ReIdentificationPrediction], distance_matrix: np.ndarray, duration: float, image: np.ndarray) -> None: ...
    def __eq__(self, other) -> bool: ...
    @property
    def duration(self) -> float: ...
    @property
    def predictions(self) -> List[ReIdentificationPrediction]: ...
    @property
    def distance_matrix(self) -> np.ndarray: ...
    @property
    def image(self) -> np.ndarray: ...

RESULT_TYPE: Incomplete

class ReIdentification(BaseService[ReIdentificationProcessor]):
    def __init__(self, model_id: str, model_config: Optional[ModelConfig] = ...) -> None: ...
    def set_per_id_gallery_limit(self, count: int, drop_method: str): ...
    def extract_features(self, image: np.ndarray, flip_horizontal: bool = ...) -> np.ndarray: ...
    def get_distances(self, image: np.ndarray, gallery_images: List[np.ndarray], flip_horizontal: bool = ..., normalize_distance: bool = ...) -> np.ndarray: ...
    def add_to_gallery(self, image: np.ndarray, id: int, flip_horizontal: bool = ...): ...
    def remove_from_gallery(self, id: int): ...
    def re_id_image(self, image: np.ndarray, top_k: int = ..., normalize_distance: bool = ..., flip_horizontal: bool = ...) -> ReIdentificationResults: ...
    def publish_analytics(self, results: ReIdentificationResults, tag: Incomplete | None = ...): ...
